/*
* Original code by ©Kosada Incorporated, released under MIT License, modified by Bodysoulspirit.
* This code may be modified and distributed under the terms of the MIT License.
* For more information, see https://vuo.org/license.
*/

#include "node.h"

VuoModuleMetadata({
					  "title" : "Are Equal (If, Then)",
					  "keywords" : ["==", "same", "identical", "equivalent", "match", "compare", "true", "false", "logic", "if", "then"],
					  "description" : "Checks if the values from a list are all equal, if yes, outputs true on the true output and fires an event, and false on the false output port if false, while blocking the other port from firing events.",
					  "version" : "1.0.1",
					  "genericTypes" : {
						  "VuoGenericType1" : {
							  "compatibleTypes" : [
								  "VuoBoolean", "VuoColor", "VuoImage", "VuoInteger",
								  "VuoPoint2d", "VuoPoint3d", "VuoPoint4d",
								  "VuoReal", "VuoScreen", "VuoText",
								  "VuoArtNetInputDevice", "VuoArtNetOutputDevice",
								  "VuoAudioInputDevice", "VuoAudioOutputDevice", "VuoAudioFrame", "VuoData",
								  "VuoCoordinateUnit", "VuoDistribution3d", "VuoDragEvent",
								  "VuoGridType",
								  "VuoHidControl", "VuoHidDevice",
								  "VuoImageFormat",
								  "VuoFont", "VuoMidiController", "VuoMidiInputDevice",
								  "VuoMidiNote", "VuoMidiOutputDevice", "VuoMidiPitchBend",
								  "VuoMultisample", "VuoBaudRate", "VuoParity",
								  "VuoOscInputDevice", "VuoOscOutputDevice",
								  "VuoRange",
								  "VuoRectangle",
								  "VuoRelativeTime", "VuoRoundingMethod",
								  "VuoSerialDevice", "VuoVertexAttribute", "VuoSyphonServerDescription",
								  "VuoTempoRange", "VuoNumberFormat", "VuoIconPosition", "VuoMovieFormat",
								  "VuoVideoFrame", "VuoVideoInputDevice",
								  "VuoTime", "VuoTimeUnit", "VuoTimeFormat", "VuoWeekday",
								  "VuoHorizontalAlignment", "VuoVerticalAlignment", "VuoAnchor"
							  ]
						  }
					  },
});

void nodeEvent
(
		VuoInputData(VuoList_VuoGenericType1) values,
		VuoInputEvent({"eventBlocking":"door","data":"values"}) valuesEvent,
		VuoOutputData(VuoBoolean) equal,
		VuoOutputEvent({"data":"equal"}) equalEvent,
		VuoOutputData(VuoBoolean) notEqual,
		VuoOutputEvent({"data":"notEqual"}) notEqualEvent
)
{
	*equal = false;
	*notEqual = false;
	unsigned long count = VuoListGetCount_VuoGenericType1(values);
	for (unsigned long i = 2; i <= count; ++i)
		if (VuoGenericType1_areEqual(VuoListGetValue_VuoGenericType1(values, i - 1), VuoListGetValue_VuoGenericType1(values, i))){
			*equal = true;
			*equalEvent = true;
		}
		else{
			*notEqual = true;
			*notEqualEvent = true;
		}
}
